@@ -37,11 +37,16 @@ current shell.
 POD
 
 
-perlbrew=perlbrew
-VERSION=0.0101
+VERSION=0.0102
 
 PERLBREW_ROOT=${PERLBREW_ROOT:-$HOME/perl5/perlbrew}
 
+if [ -x "$PERLBREW_ROOT/bin/perlbrew" ]; then
+    perlbrew="$PERLBREW_ROOT/bin/perlbrew"
+else
+    perlbrew=perlbrew
+fi
+
 if [ ! -f "$PERLBREW_ROOT/etc/bashrc" ]; then
     $perlbrew init
 fi
@@ -51,7 +56,7 @@ if [ -n "$BASH_VERSION" ]; then
 fi
 
 if [ "$1" = "-v" ]; then
-    echo "$perlbrew $VERSION"
+    echo "perluse $VERSION"
     exit 1
 fi
 
